@@ -3,14 +3,10 @@ use std::path::PathBuf;
 /// Validates a vector of paths.
 ///
 /// Returns error on:
+///
 ///     - Empty input vector
 ///     - Non-existing path in input vector
 pub fn validate_paths(sources: Vec<PathBuf>) -> Result<(), String> {
-    // Abort on empty input.
-    if sources.len() == 0 {
-        return Err("Missing input path(s)".to_string());
-    }
-
     // Check for validity of given source paths.
     let mut invalid_sources: Vec<PathBuf> = Vec::new();
     for source in sources.iter() {
