@@ -8,7 +8,14 @@ fn get_target(path: PathBuf) -> PathBuf {
         .to_path_buf();
 }
 
-pub fn bak(sources: &mut Vec<PathBuf>, quiet: bool) -> Result<(), String> {
+pub fn bak(
+    source: PathBuf,
+    more_sources: Vec<PathBuf>,
+    quiet: bool,
+) -> Result<(), String> {
+    let sources = &mut vec![source];
+    sources.extend(more_sources);
+
     // Validate input paths.
     super::_shared_functions::validate_paths(sources.to_vec())?;
 
